/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include <QPainter>

#include <U2Core/U2OpStatus.h>
#include <U2Core/U2Region.h>
#include <U2Core/U2SafePoints.h>

namespace U2 {

class CustomExportSettings : public QObject {
    Q_OBJECT
public:
    virtual ~CustomExportSettings() {
    }
signals:
    void si_changed();
};

class ExportImagePainter : public QObject {
public:
    virtual ~ExportImagePainter() {
    }

    virtual void paint(QPainter& p, CustomExportSettings* settings) const = 0;
    virtual QSize getImageSize(CustomExportSettings* settings) const = 0;
    virtual bool canPaintSvg(CustomExportSettings* settings, U2OpStatus& os) const = 0;
};

}  // namespace U2
